EagerDataset
============

.. currentmodule:: pykeen.datasets.base

.. autoclass:: EagerDataset
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~EagerDataset.iter_extra_repr

   .. rubric:: Methods Documentation

   .. automethod:: iter_extra_repr
